@@ -1,6 +1,5 @@
 import os
 import sys
-from pathlib import Path
 
 import click
 from ploomber import __version__
@@ -18,13 +17,26 @@ def cli():
 
 
 @cli.command()
-def scaffold():
+@click.option(
+    '--conda',
+    is_flag=True,
+    help='Use conda (environemnt.yml)',
+)
+@click.option(
+    '--package',
+    is_flag=True,
+    help='Use package template (setup.py)',
+)
+def scaffold(conda, package):
     """Create new projects and add template tasks
     """
-    if Path('pipeline.yaml').exists():
-        _scaffold.add()
+    loaded = _scaffold.load_dag()
+
+    if loaded:
+        spec, path_to_spec = loaded
+        _scaffold.add(spec, path_to_spec)
     else:
-        scaffold_project.cli(project_path=None)
+        scaffold_project.cli(project_path=None, conda=conda, package=package)
 
 
 @cli.command()
