@@ -1,3 +1,7 @@
+"""
+A placeholder Product that doesn't do anything, used internally for
+InMemoryDAG
+"""
 from ploomber.products import Product
 from ploomber.placeholders.Placeholder import Placeholder
 
