@@ -8,6 +8,8 @@ import shlex
 import subprocess
 import pdb
 import functools
+from pathlib import Path
+from collections.abc import Mapping
 
 from IPython.terminal.debugger import TerminalPdb, Pdb
 
@@ -20,13 +22,25 @@ from ploomber.constants import TaskStatus
 from ploomber.sources.interact import CallableInteractiveDeveloper
 from ploomber.tasks._params import Params
 from ploomber.io.loaders import _file_load
+from ploomber.products import MetaProduct, File
+
+
+def _unserializer(product, unserializer):
+    # this happens when we have a task group
+    if isinstance(product, Mapping):
+        return {k: unserializer(p) for k, p in product.items()}
+    else:
+        return unserializer(product)
 
 
 def _unserialize_params(params_original, unserializer):
+    """
+    User the user-provided function to unserialize params['upstream']
+    """
     params = params_original.to_dict()
 
     params['upstream'] = {
-        k: unserializer(product=v)
+        k: _unserializer(v, unserializer)
         for k, v in params['upstream'].items()
     }
 
@@ -98,6 +112,7 @@ class PythonCallable(Task):
             product = params.pop('product')
         else:
             product = params['product']
+            _ensure_parents_exist(product)
 
         # call function
         out = self.source.primitive(**params)
@@ -448,3 +463,16 @@ class Input(Task):
         # this should be __true but we can't due to
         # https://bugs.python.org/issue33007
         return True
+
+
+def _ensure_parents_exist(product):
+    if isinstance(product, MetaProduct):
+        for prod in product:
+            _ensure_file_parents_exist(prod)
+    else:
+        _ensure_file_parents_exist(product)
+
+
+def _ensure_file_parents_exist(product):
+    if isinstance(product, File):
+        Path(product).parent.mkdir(parents=True, exist_ok=True)
