@@ -2,16 +2,22 @@ from ploomber.testing.sql.SQLParser import SQLParser
 from ploomber.testing.sql.functions import (
     nulls_in_columns,
     distinct_values_in_column,
-    duplicates_in_column,
     range_in_column,
     exists_row_where,
 )
+from ploomber.testing.sql.duplicated import (
+    duplicates_in_column,
+    duplicates_stats,
+    assert_no_duplicates_in_column,
+)
 
 __all__ = [
     'nulls_in_columns',
     'distinct_values_in_column',
-    'duplicates_in_column',
     'range_in_column',
     'exists_row_where',
     'SQLParser',
+    'duplicates_in_column',
+    'duplicates_stats',
+    'assert_no_duplicates_in_column',
 ]
