@@ -110,7 +110,6 @@ def find_file_recursively(name, max_levels_up=6, starting_dir=None):
         Absolute path to the file
     """
     current_dir = starting_dir or os.getcwd()
-    # if we don't resolve, we can't get parents of '.'
     current_dir = Path(current_dir).resolve()
     path_to_file = None
 
@@ -127,7 +126,26 @@ def find_file_recursively(name, max_levels_up=6, starting_dir=None):
 
 
 def find_root_recursively(starting_dir=None, raise_=False):
-    options = ['environment.yml', 'requirements.txt', 'setup.py']
+    """
+    Finds a project root by looking recursively for environment files
+    or a setup.py file. If None of those files exist, it returns the current
+    working directory if there is a pipeline.yaml file
+
+    Parameters
+    ---------
+    starting_dir : str or pathlib.Path
+        The directory to start the search
+
+    raise_ : bool
+        Whether to raise an error or not if no root folder is found
+    """
+    options = [
+        'environment.yml',
+        'environment.lock.yml',
+        'requirements.txt',
+        'requirements.lock.txt',
+        'setup.py',
+    ]
 
     for name in options:
         path = find_file_recursively(name,
